package Qt::Gui::QAbstractPageSetupDialog;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QAbstractPageSetupDialog
# file     : QtGui/qabstractpagesetupdialog.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_02';
our $ISA     = qw/Qt::Gui::QDialog/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QAbstractPageSetupDialog

=head1 PUBLIC METHODS

=over

=item   QAbstractPageSetupDialog(QPrinter * printer, QWidget * parent)

=item   QAbstractPageSetupDialog(QPrinter * printer, QWidget * parent = 0)

=item   QAbstractPageSetupDialog(QAbstractPageSetupDialogPrivate & ptr, QPrinter * printer, QWidget * parent)

=item   QAbstractPageSetupDialog(QAbstractPageSetupDialogPrivate & ptr, QPrinter * printer, QWidget * parent = 0)

=item   ~QAbstractPageSetupDialog()

=item  void done(int result)

=item  int exec()

=item  QPrinter * printer()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
